@@ -1,10 +1,10 @@
 use crate::director::director;
+use crate::sorts::out_of_place_sort::out_of_place_sort;
 use crate::tuning_parameters::TuningParameters;
 use crate::utils::*;
 use crate::RadixKey;
 use arbitrary_chunks::ArbitraryChunks;
 use rayon::prelude::*;
-use crate::sorts::out_of_place_sort::out_of_place_sort;
 
 pub fn recombinating_sort<T>(tuning: &TuningParameters, bucket: &mut [T], level: usize)
 where
@@ -17,7 +17,7 @@ where
     let locals: Vec<([usize; 256], [usize; 256])> = bucket
         .par_chunks(chunk_size)
         .zip(tmp_bucket.par_chunks_mut(chunk_size))
-        .map(|(chunk, tmp_chunk) | {
+        .map(|(chunk, tmp_chunk)| {
             let counts = get_counts(chunk, level);
 
             out_of_place_sort(chunk, tmp_chunk, &counts, level);
@@ -74,26 +74,12 @@ where
 #[cfg(test)]
 mod tests {
     use crate::sorts::recombinating_sort::recombinating_sort;
-    use crate::test_utils::sort_comparison_suite;
+    use crate::test_utils::{sort_comparison_suite, NumericTest};
     use crate::tuning_parameters::TuningParameters;
-    use crate::RadixKey;
-    use nanorand::{RandomGen, WyRand};
-    use std::fmt::Debug;
-    use std::ops::{Shl, Shr};
 
     fn test_recombinating_sort<T>(shift: T)
     where
-        T: RadixKey
-            + Ord
-            + RandomGen<WyRand>
-            + Clone
-            + Debug
-            + Send
-            + Sized
-            + Copy
-            + Sync
-            + Shl<Output = T>
-            + Shr<Output = T>,
+        T: NumericTest<T>,
     {
         let tuning = TuningParameters::new(T::LEVELS);
         sort_comparison_suite(shift, |inputs| {
